api.assets.v1.test_helpers.scan package — Argus-Toolbelt 1.0 documentation

# api.assets.v1.test_helpers.scan package

## Submodules

## api.assets.v1.test_helpers.scan.host_asset_bulk_scanned module

`api.assets.v1.test_helpers.scan.host_asset_bulk_scanned.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/scan, respond with HTTP 403

`api.assets.v1.test_helpers.scan.host_asset_bulk_scanned.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/scan, respond with HTTP 404

`api.assets.v1.test_helpers.scan.host_asset_bulk_scanned.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/scan, respond with HTTP 200

`api.assets.v1.test_helpers.scan.host_asset_bulk_scanned.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/scan, respond with HTTP 401

## api.assets.v1.test_helpers.scan.host_asset_scanned module

`api.assets.v1.test_helpers.scan.host_asset_scanned.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/scan/w+/w+, respond with HTTP 403

`api.assets.v1.test_helpers.scan.host_asset_scanned.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/scan/w+/w+, respond with HTTP 404

`api.assets.v1.test_helpers.scan.host_asset_scanned.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/scan/w+/w+, respond with HTTP 200

`api.assets.v1.test_helpers.scan.host_asset_scanned.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/scan/w+/w+, respond with HTTP 401

## Module contents